package cn.iocoder.yudao.module.inspection.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import cn.iocoder.yudao.module.inspection.entity.InspectionNewsAssociation;
import cn.iocoder.yudao.module.inspection.entity.InspectionNewsComment;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;


/**
 * 【请填写功能名称】Mapper接口
 *
 * @author ruoyi
 * @date 2023-08-07
 */
@Mapper
public interface InspectionNewsCommentMapper  extends BaseMapper<InspectionNewsComment>
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public InspectionNewsComment selectInspectionNewsCommentById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param inspectionNewsComment 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public IPage<InspectionNewsComment> selectInspectionNewsCommentList(Page<InspectionNewsComment> page, @Param("vo") InspectionNewsComment inspectionNewsComment);

    /**
     * 新增【请填写功能名称】
     *
     * @param inspectionNewsComment 【请填写功能名称】
     * @return 结果
     */
    public int insertInspectionNewsComment(InspectionNewsComment inspectionNewsComment);

    /**
     * 修改【请填写功能名称】
     *
     * @param inspectionNewsComment 【请填写功能名称】
     * @return 结果
     */
    public int updateInspectionNewsComment(InspectionNewsComment inspectionNewsComment);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteInspectionNewsCommentById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInspectionNewsCommentByIds(Long[] ids);
}
